@@ -1,9 +1,6 @@
 //! `cat` subcommand
 
-use crate::{
-    commands::{open_repository, open_repository_indexed},
-    status_err, Application, RUSTIC_APP,
-};
+use crate::{Application, RUSTIC_APP, status_err};
 
 use abscissa_core::{Command, Runnable, Shutdown};
 
@@ -35,6 +32,8 @@ enum CatSubCmd {
     Snapshot(IdOpt),
     /// Display a tree within a snapshot
     Tree(TreeOpts),
+    /// Display the masterkey
+    Masterkey,
 }
 
 #[derive(Default, clap::Parser, Debug)]
@@ -62,24 +61,29 @@ impl Runnable for CatCmd {
 impl CatCmd {
     fn inner_run(&self) -> Result<()> {
         let config = RUSTIC_APP.config();
-        let data =
-            match &self.cmd {
-                CatSubCmd::Config => {
-                    open_repository(&config.repository)?.cat_file(FileType::Config, "")?
-                }
-                CatSubCmd::Index(opt) => {
-                    open_repository(&config.repository)?.cat_file(FileType::Index, &opt.id)?
-                }
-                CatSubCmd::Snapshot(opt) => {
-                    open_repository(&config.repository)?.cat_file(FileType::Snapshot, &opt.id)?
-                }
-                CatSubCmd::TreeBlob(opt) => open_repository_indexed(&config.repository)?
-                    .cat_blob(BlobType::Tree, &opt.id)?,
-                CatSubCmd::DataBlob(opt) => open_repository_indexed(&config.repository)?
-                    .cat_blob(BlobType::Data, &opt.id)?,
-                CatSubCmd::Tree(opt) => open_repository_indexed(&config.repository)?
-                    .cat_tree(&opt.snap, |sn| config.snapshot_filter.matches(sn))?,
-            };
+        let data = match &self.cmd {
+            CatSubCmd::Config => config
+                .repository
+                .run_open(|repo| Ok(repo.cat_file(FileType::Config, "")?))?,
+            CatSubCmd::Index(opt) => config
+                .repository
+                .run_open(|repo| Ok(repo.cat_file(FileType::Index, &opt.id)?))?,
+            CatSubCmd::Snapshot(opt) => config
+                .repository
+                .run_open(|repo| Ok(repo.cat_file(FileType::Snapshot, &opt.id)?))?,
+            CatSubCmd::TreeBlob(opt) => config
+                .repository
+                .run_indexed(|repo| Ok(repo.cat_blob(BlobType::Tree, &opt.id)?))?,
+            CatSubCmd::DataBlob(opt) => config
+                .repository
+                .run_indexed(|repo| Ok(repo.cat_blob(BlobType::Data, &opt.id)?))?,
+            CatSubCmd::Tree(opt) => config.repository.run_indexed(|repo| {
+                Ok(repo.cat_tree(&opt.snap, |sn| config.snapshot_filter.matches(sn))?)
+            })?,
+            CatSubCmd::Masterkey => config
+                .repository
+                .run_open(|repo| Ok(serde_json::to_vec(&repo.key())?.into()))?,
+        };
         println!("{}", String::from_utf8(data.to_vec())?);
 
         Ok(())
