@@ -1,40 +1,39 @@
 //! `forget` subcommand
 
-use crate::{
-    commands::open_repository, helpers::table_with_titles, status_err, Application, RusticConfig,
-    RUSTIC_APP,
-};
+use crate::repository::{OpenRepo, get_grouped_snapshots};
+use crate::{Application, RUSTIC_APP, RusticConfig, helpers::table_with_titles, status_err};
 
-use abscissa_core::{config::Override, Shutdown};
 use abscissa_core::{Command, FrameworkError, Runnable};
+use abscissa_core::{Shutdown, config::Override};
 use anyhow::Result;
-
-use chrono::Local;
 use conflate::Merge;
+use jiff::Zoned;
+use log::info;
+use rustic_core::repofile::RusticTime;
 use serde::{Deserialize, Serialize};
-use serde_with::{serde_as, DisplayFromStr};
+use serde_with::{DisplayFromStr, serde_as};
 
 use crate::{commands::prune::PruneCmd, filtering::SnapshotFilter};
 
-use rustic_core::{
-    ForgetGroup, ForgetGroups, ForgetSnapshot, KeepOptions, SnapshotGroup, SnapshotGroupCriterion,
-};
+use rustic_core::{ForgetGroups, ForgetSnapshot, KeepOptions, SnapshotGroupCriterion};
 
 /// `forget` subcommand
 #[derive(clap::Parser, Command, Debug)]
 pub(super) struct ForgetCmd {
     /// Snapshots to forget. If none is given, use filter options to filter from all snapshots
+    ///
+    /// Snapshots can be identified the following ways: "01a2b3c4" or "latest" or "latest~N" (N >= 0)
     #[clap(value_name = "ID")]
     ids: Vec<String>,
 
+    /// Set the date/time (e.g. "2021-01-21) to use when evaluating retention rules; can be used to test the rules (default: now)
+    #[clap(long,value_parser = RusticTime::parse_system)]
+    pub forget_time: Option<Zoned>,
+
     /// Show infos in json format
     #[clap(long)]
     json: bool,
 
-    /// Don't show any output
-    #[clap(long, conflicts_with = "json")]
-    quiet: bool,
-
     /// Forget options
     #[clap(flatten)]
     config: ForgetOptions,
@@ -91,7 +90,11 @@ pub struct ForgetOptions {
 
 impl Runnable for ForgetCmd {
     fn run(&self) {
-        if let Err(err) = self.inner_run() {
+        if let Err(err) = RUSTIC_APP
+            .config()
+            .repository
+            .run_open(|repo| self.inner_run(repo))
+        {
             status_err!("{}", err);
             RUSTIC_APP.shutdown(Shutdown::Crash);
         };
@@ -102,56 +105,46 @@ impl ForgetCmd {
     /// be careful about self vs `RUSTIC_APP.config()` usage
     /// only the `RUSTIC_APP.config()` involves the TOML and ENV merged configurations
     /// see <https://github.com/rustic-rs/rustic/issues/1242>
-    fn inner_run(&self) -> Result<()> {
+    fn inner_run(&self, repo: OpenRepo) -> Result<()> {
         let config = RUSTIC_APP.config();
-        let repo = open_repository(&config.repository)?;
 
-        let group_by = config.forget.group_by.unwrap_or_default();
+        let group_by = config
+            .forget
+            .group_by
+            .or(config.global.group_by)
+            .unwrap_or_default();
+
+        if let Some(time) = &self.forget_time {
+            info!("using time: {time}");
+        }
+        let now = self.forget_time.clone().unwrap_or_else(Zoned::now);
 
         let groups = if self.ids.is_empty() {
-            repo.get_forget_snapshots(&config.forget.keep, group_by, |sn| {
-                config.forget.filter.matches(sn)
-            })?
+            ForgetGroups::from_grouped_snapshots_with_retention(
+                get_grouped_snapshots(&repo, group_by, &[])?,
+                &config.forget.keep,
+                &now,
+            )?
         } else {
-            let now = Local::now();
-            let item = ForgetGroup {
-                group: SnapshotGroup::default(),
-                snapshots: repo
-                    .get_snapshots(&self.ids)?
-                    .into_iter()
-                    .map(|sn| {
-                        if sn.must_keep(now) {
-                            ForgetSnapshot {
-                                snapshot: sn,
-                                keep: true,
-                                reasons: vec!["snapshot".to_string()],
-                            }
-                        } else {
-                            ForgetSnapshot {
-                                snapshot: sn,
-                                keep: false,
-                                reasons: vec!["id argument".to_string()],
-                            }
-                        }
-                    })
-                    .collect(),
-            };
-            ForgetGroups(vec![item])
+            ForgetGroups::from_snapshots(
+                repo.get_snapshots_from_strs(&self.ids, |sn| config.snapshot_filter.matches(sn))?,
+                &now,
+            )
         };
 
         if self.json {
             let mut stdout = std::io::stdout();
             serde_json::to_writer_pretty(&mut stdout, &groups)?;
-        } else if !self.quiet {
+        } else {
             print_groups(&groups);
         }
 
         let forget_snaps = groups.into_forget_ids();
 
         match (forget_snaps.is_empty(), config.global.dry_run, self.json) {
-            (true, _, false) => println!("nothing to remove"),
+            (true, _, false) => info!("nothing to remove"),
             (false, true, false) => {
-                println!("would have removed the following snapshots:\n {forget_snaps:?}");
+                info!("would have removed {} snapshots.", forget_snaps.len());
             }
             (false, false, _) => {
                 repo.delete_snapshots(&forget_snaps)?;
@@ -175,10 +168,8 @@ impl ForgetCmd {
 ///
 /// * `groups` - forget groups to print
 fn print_groups(groups: &ForgetGroups) {
-    for ForgetGroup { group, snapshots } in &groups.0 {
-        if !group.is_empty() {
-            println!("snapshots for {group}");
-        }
+    let config = RUSTIC_APP.config();
+    for group in &groups.0 {
         let mut table = table_with_titles([
             "ID", "Time", "Host", "Label", "Tags", "Paths", "Action", "Reason",
         ]);
@@ -187,9 +178,9 @@ fn print_groups(groups: &ForgetGroups) {
             snapshot: sn,
             keep,
             reasons,
-        } in snapshots
+        } in &group.items
         {
-            let time = sn.time.format("%Y-%m-%d %H:%M:%S").to_string();
+            let time = config.global.format_time(&sn.time).to_string();
             let tags = sn.tags.formatln();
             let paths = sn.paths.formatln();
             let action = if *keep { "keep" } else { "remove" };
@@ -206,8 +197,10 @@ fn print_groups(groups: &ForgetGroups) {
             ]);
         }
 
-        println!();
-        println!("{table}");
-        println!();
+        if !group.group_key.is_empty() {
+            info!("snapshots for {}:\n{table}", group.group_key);
+        } else {
+            info!("snapshots:\n{table}");
+        }
     }
 }
