@@ -18,7 +18,7 @@ use std::{ffi::OsStr, path::PathBuf};
 
 use crate::{
     Application, RUSTIC_APP, RusticConfig,
-    repository::{CliIndexedRepo, get_filtered_snapshots},
+    repository::{IndexedRepo, get_filtered_snapshots},
     status_err,
 };
 
@@ -30,7 +30,7 @@ pub struct MountCmd {
     #[merge(strategy=conflate::option::overwrite_none)]
     path_template: Option<String>,
 
-    /// The time template to use to display times in the path template. See https://docs.rs/chrono/latest/chrono/format/strftime/index.html for format options. [default: "%Y-%m-%d_%H-%M-%S"]
+    /// The time template to use to display times in the path template. See https://pubs.opengroup.org/onlinepubs/009695399/functions/strftime.html for format options. [default: "%Y-%m-%d_%H-%M-%S"]
     #[clap(long)]
     #[merge(strategy=conflate::option::overwrite_none)]
     time_template: Option<String>,
@@ -51,6 +51,8 @@ pub struct MountCmd {
     mount_point: Option<PathBuf>,
 
     /// Specify directly which snapshot/path to mount
+    ///
+    /// Snapshot can be identified the following ways: "01a2b3c4" or "latest" or "latest~N" (N >= 0)
     #[clap(value_name = "SNAPSHOT[:PATH]")]
     #[merge(strategy=conflate::option::overwrite_none)]
     snapshot_path: Option<String>,
@@ -109,7 +111,7 @@ impl MountCmd {
         }
     }
 
-    fn inner_run(&self, repo: CliIndexedRepo) -> Result<()> {
+    fn inner_run(&self, repo: IndexedRepo) -> Result<()> {
         let config = RUSTIC_APP.config();
 
         // We have merged the config file, the command line options, and the
