@@ -1,9 +1,10 @@
 //! `repoinfo` subcommand
 
 use crate::{
-    commands::{get_repository, open_repository},
+    Application, RUSTIC_APP,
     helpers::{bytes_size_to_string, table_right_from},
-    status_err, Application, RUSTIC_APP,
+    repository::Repo,
+    status_err,
 };
 
 use abscissa_core::{Command, Runnable, Shutdown};
@@ -15,7 +16,7 @@ use rustic_core::{IndexInfos, RepoFileInfo, RepoFileInfos};
 /// `repoinfo` subcommand
 #[derive(clap::Parser, Command, Debug)]
 pub(crate) struct RepoInfoCmd {
-    /// Only scan repository files (doesn't need repository password)
+    /// Only scan repository files (doesn't need credentials)
     #[clap(long)]
     only_files: bool,
 
@@ -30,7 +31,11 @@ pub(crate) struct RepoInfoCmd {
 
 impl Runnable for RepoInfoCmd {
     fn run(&self) {
-        if let Err(err) = self.inner_run() {
+        if let Err(err) = RUSTIC_APP
+            .config()
+            .repository
+            .run(|repo| self.inner_run(repo))
+        {
             status_err!("{}", err);
             RUSTIC_APP.shutdown(Shutdown::Crash);
         };
@@ -48,20 +53,17 @@ struct Infos {
 }
 
 impl RepoInfoCmd {
-    fn inner_run(&self) -> Result<()> {
+    fn inner_run(&self, repo: Repo) -> Result<()> {
         let config = RUSTIC_APP.config();
-
         let infos = Infos {
             files: (!self.only_index)
-                .then(|| -> Result<_> {
-                    let repo = get_repository(&config.repository)?;
-                    Ok(repo.infos_files()?)
-                })
+                .then(|| -> Result<_> { Ok(repo.infos_files()?) })
                 .transpose()?,
             index: (!self.only_files)
                 .then(|| -> Result<_> {
-                    let repo = open_repository(&config.repository)?;
-                    Ok(repo.infos_index()?)
+                    Ok(repo
+                        .open(&config.repository.credential_opts)?
+                        .infos_index()?)
                 })
                 .transpose()?,
         };
@@ -176,8 +178,12 @@ pub fn print_index_info(index_info: IndexInfos) {
         _ = table.add_row([
             format!("{:?} packs", packs.blob_type),
             packs.count.to_string(),
-            packs.min_size.map_or("-".to_string(), bytes_size_to_string),
-            packs.max_size.map_or("-".to_string(), bytes_size_to_string),
+            packs
+                .min_size
+                .map_or_else(|| "-".to_string(), bytes_size_to_string),
+            packs
+                .max_size
+                .map_or_else(|| "-".to_string(), bytes_size_to_string),
         ]);
     }
     for packs in index_info.packs_delete {
@@ -185,8 +191,12 @@ pub fn print_index_info(index_info: IndexInfos) {
             _ = table.add_row([
                 format!("{:?} packs to delete", packs.blob_type),
                 packs.count.to_string(),
-                packs.min_size.map_or("-".to_string(), bytes_size_to_string),
-                packs.max_size.map_or("-".to_string(), bytes_size_to_string),
+                packs
+                    .min_size
+                    .map_or_else(|| "-".to_string(), bytes_size_to_string),
+                packs
+                    .max_size
+                    .map_or_else(|| "-".to_string(), bytes_size_to_string),
             ]);
         }
     }
