@@ -5,6 +5,7 @@
 //! for specifying it.
 
 pub(crate) mod hooks;
+pub(crate) mod logging;
 pub(crate) mod progress_options;
 
 use std::{
@@ -19,6 +20,7 @@ use clap::{Parser, ValueHint};
 use conflate::Merge;
 use directories::ProjectDirs;
 use itertools::Itertools;
+use jiff::{Timestamp, Zoned, tz::TimeZone};
 use log::Level;
 use reqwest::Url;
 use rustic_core::SnapshotGroupCriterion;
@@ -34,7 +36,7 @@ use crate::commands::webdav::WebDavCmd;
 
 use crate::{
     commands::{backup::BackupCmd, copy::CopyCmd, forget::ForgetOptions},
-    config::{hooks::Hooks, progress_options::ProgressOptions},
+    config::{hooks::Hooks, logging::LoggingOptions, progress_options::ProgressOptions},
     filtering::SnapshotFilter,
     repository::AllRepositoryOptions,
 };
@@ -202,19 +204,10 @@ pub struct GlobalOptions {
     #[merge(strategy=conflate::bool::overwrite_false)]
     pub check_index: bool,
 
-    /// Use this log level [default: info]
-    #[clap(long, global = true, env = "RUSTIC_LOG_LEVEL")]
-    #[merge(strategy=conflate::option::overwrite_none)]
-    pub log_level: Option<String>,
-
-    /// Write log messages to the given file instead of printing them.
-    ///
-    /// # Note
-    ///
-    /// Warnings and errors are still additionally printed unless they are ignored by `--log-level`
-    #[clap(long, global = true, env = "RUSTIC_LOG_FILE", value_name = "LOGFILE", value_hint = ValueHint::FilePath)]
-    #[merge(strategy=conflate::option::overwrite_none)]
-    pub log_file: Option<PathBuf>,
+    /// Settings to customize logging
+    #[clap(flatten)]
+    #[serde(flatten)]
+    pub logging_options: LoggingOptions,
 
     /// Settings to customize progress bars
     #[clap(flatten)]
@@ -256,6 +249,11 @@ pub struct GlobalOptions {
     #[clap(long, global = true, env = "RUSTIC_OTEL", value_name = "ENDPOINT_URL", value_hint = ValueHint::Url)]
     #[merge(strategy=conflate::option::overwrite_none)]
     pub opentelemetry: Option<Url>,
+
+    /// Show time offsets instead of converting to system time zone
+    #[clap(long, global = true, env = "RUSTIC_SHOW_TIME_OFFSET")]
+    #[merge(strategy=conflate::bool::overwrite_false)]
+    pub show_time_offset: bool,
 }
 
 pub fn parse_labels(s: &str) -> Result<BTreeMap<String, String>> {
@@ -277,6 +275,24 @@ impl GlobalOptions {
     pub fn is_metrics_configured(&self) -> bool {
         self.prometheus.is_some() || self.opentelemetry.is_some()
     }
+
+    pub fn format_timestamp(&self, timestamp: Timestamp) -> String {
+        self.format_time(&timestamp.to_zoned(TimeZone::UTC))
+            .to_string()
+    }
+
+    pub fn format_time(&self, time: &Zoned) -> impl Display {
+        if self.show_time_offset {
+            time.strftime("%Y-%m-%d %H:%M:%S%z")
+        } else {
+            let tz = TimeZone::system();
+            if time.offset() == tz.to_offset(time.timestamp()) {
+                time.strftime("%Y-%m-%d %H:%M:%S")
+            } else {
+                time.with_time_zone(tz).strftime("%Y-%m-%d %H:%M:%S*")
+            }
+        }
+    }
 }
 
 /// Get the paths to the config file
